@@ -1,8 +1,31 @@
 package MooseX::NonMoose::InsideOut;
 BEGIN {
-  $MooseX::NonMoose::InsideOut::VERSION = '0.08';
+  $MooseX::NonMoose::InsideOut::VERSION = '0.09';
 }
 use Moose::Exporter;
+# ABSTRACT: easy subclassing of non-Moose non-hashref classes
+
+
+my ($import, $unimport, $init_meta) = Moose::Exporter->build_import_methods(
+    metaclass_roles          => ['MooseX::NonMoose::Meta::Role::Class'],
+    constructor_class_roles  => ['MooseX::NonMoose::Meta::Role::Constructor'],
+    instance_metaclass_roles => ['MooseX::InsideOut::Role::Meta::Instance'],
+    install                  => [qw(import unimport)],
+);
+
+sub init_meta {
+    my $package = shift;
+    my %options = @_;
+    Carp::cluck('Roles have no use for MooseX::NonMoose')
+        if Class::MOP::class_of($options{for_class})->isa('Moose::Meta::Role');
+    $package->$init_meta(@_);
+}
+
+
+1;
+
+__END__
+=pod
 
 =head1 NAME
 
@@ -10,7 +33,7 @@ MooseX::NonMoose::InsideOut - easy subclassing of non-Moose non-hashref classes
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =head1 SYNOPSIS
 
@@ -41,22 +64,7 @@ version 0.08
 
 =head1 DESCRIPTION
 
-=cut
-
-my ($import, $unimport, $init_meta) = Moose::Exporter->build_import_methods(
-    metaclass_roles          => ['MooseX::NonMoose::Meta::Role::Class'],
-    constructor_class_roles  => ['MooseX::NonMoose::Meta::Role::Constructor'],
-    instance_metaclass_roles => ['MooseX::InsideOut::Role::Meta::Instance'],
-    install                  => [qw(import unimport)],
-);
-
-sub init_meta {
-    my $package = shift;
-    my %options = @_;
-    Carp::cluck('Roles have no use for MooseX::NonMoose')
-        if Class::MOP::class_of($options{for_class})->isa('Moose::Meta::Role');
-    $package->$init_meta(@_);
-}
+=for Pod::Coverage   init_meta
 
 =head1 AUTHOR
 
@@ -64,11 +72,10 @@ sub init_meta {
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2009 by Jesse Luehrs.
+This software is copyright (c) 2010 by Jesse Luehrs.
 
 This is free software; you can redistribute it and/or modify it under
-the same terms as perl itself.
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
-1;
\ No newline at end of file
